/*
 *  Copyright (c) 2012-2016, Bruno Levy
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *  this list of conditions and the following disclaimer in the documentation
 *  and/or other materials provided with the distribution.
 *  * Neither the name of the ALICE Project-Team nor the names of its
 *  contributors may be used to endorse or promote products derived from this
 *  software without specific prior written permission.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 *  If you modify this software, you should include a notice giving the
 *  name of the person performing the modification, the date of modification,
 *  and the reason for such modification.
 *
 *  Contact: Bruno Levy
 *
 *     Bruno.Levy@inria.fr
 *     http://www.loria.fr/~levy
 *
 *     ALICE Project
 *     LORIA, INRIA Lorraine, 
 *     Campus Scientifique, BP 239
 *     54506 VANDOEUVRE LES NANCY CEDEX 
 *     FRANCE
 *
 */

#include <geogram_gfx/basic/common.h>
#include <geogram_gfx/basic/GLSL.h>
#include <geogram_gfx/basic/GL.h>


namespace GLUP {

    GLuint create_sphere_display_list();
    

#ifdef  GEO_GL_LEGACY    
    GLuint create_sphere_display_list() {
	
	const unsigned int SPHERE_MODEL_NB_PTS = 642;
	const unsigned int SPHERE_MODEL_NB_TRIANGLES = 1280;
	
	static float SPHERE_MODEL_PTS[SPHERE_MODEL_NB_PTS*3] = {
	    0.0f, 0.0f, 1.0f,
	    0.894427f, 0.0f, 0.447214f,
	    0.276393f, 0.850651f, 0.447214f,
	    -0.723607f, 0.525731f, 0.447214f,
	    -0.723607f, -0.525731f, 0.447214f,
	    0.276393f, -0.850651f, 0.447214f,
	    0.723607f, 0.525731f, -0.447214f,
	    0.723607f, -0.525731f, -0.447214f,
	    -0.276393f, 0.850651f, -0.447214f,
	    -0.894427f, 0.0f, -0.447214f,
	    -0.276393f, -0.850651f, -0.447214f,
	    0.0f, 0.0f, -1.0f,
	    0.525731f, 0.0f, 0.850651f,
	    0.688191f, 0.5f, 0.525731f,
	    0.16246f, 0.5f, 0.850651f,
	    -0.262866f, 0.809017f, 0.525731f,
	    -0.425325f, 0.309017f, 0.850651f,
	    -0.850651f, 0.0f, 0.525731f,
	    -0.425325f, -0.309017f, 0.850651f,
	    -0.262866f, -0.809017f, 0.525731f,
	    0.16246f, -0.5f, 0.850651f,
	    0.688191f, -0.5f, 0.525731f,
	    0.587785f, -0.809017f, -2.61678e-010f,
	    0.951057f, -0.309017f, 4.48188e-008f,
	    0.850651f, 0.0f, -0.525731f,
	    0.951057f, 0.309017f, 4.48188e-008f,
	    0.587785f, 0.809017f, -2.61678e-010f,
	    0.262866f, 0.809017f, -0.525731f,
	    0.0f, 1.0f, 0.0f,
	    -0.587785f, 0.809017f, 2.61678e-010f,
	    -0.688191f, 0.5f, -0.525731f,
	    -0.951057f, 0.309017f, -4.48188e-008f,
	    -0.951057f, -0.309017f, -4.48188e-008f,
	    -0.688191f, -0.5f, -0.525731f,
	    -0.587785f, -0.809017f, 2.61678e-010f,
	    0.0f, -1.0f, 0.0f,
	    0.262866f, -0.809017f, -0.525731f,
	    0.425325f, -0.309017f, -0.850651f,
	    0.425325f, 0.309017f, -0.850651f,
	    -0.16246f, 0.5f, -0.850651f,
	    -0.16246f, -0.5f, -0.850651f,
	    -0.525731f, 0.0f, -0.850651f,
	    0.273267f, 0.0f, 0.961938f,
	    0.822619f, 0.259892f, 0.505721f,
	    0.228109f, 0.702046f, 0.674609f,
	    0.00703146f, 0.862668f, 0.505721f,
	    -0.597196f, 0.433889f, 0.674609f,
	    -0.818274f, 0.273267f, 0.505721f,
	    -0.597196f, -0.433889f, 0.674609f,
	    -0.512752f, -0.69378f, 0.505721f,
	    0.228109f, -0.702046f, 0.674609f,
	    0.501375f, -0.702046f, 0.505721f,
	    0.449186f, -0.862668f, 0.232454f,
	    0.870463f, -0.433889f, -0.232454f,
	    0.818274f, -0.273267f, -0.505721f,
	    0.870463f, 0.433889f, -0.232454f,
	    0.68164f, 0.69378f, -0.232454f,
	    0.512752f, 0.69378f, -0.505721f,
	    -0.143665f, 0.961938f, -0.232454f,
	    -0.449186f, 0.862668f, -0.232454f,
	    -0.501375f, 0.702046f, -0.505721f,
	    -0.959253f, 0.160622f, -0.232454f,
	    -0.959253f, -0.160622f, -0.232454f,
	    -0.822619f, -0.259892f, -0.505721f,
	    -0.449186f, -0.862668f, -0.232454f,
	    -0.143665f, -0.961938f, -0.232454f,
	    -0.00703146f, -0.862668f, -0.505721f,
	    0.597196f, -0.433889f, -0.674609f,
	    0.221077f, 0.160622f, -0.961938f,
	    -0.084444f, 0.259892f, -0.961938f,
	    -0.228109f, -0.702046f, -0.674609f,
	    -0.273267f, 0.0f, -0.961938f,
	    0.738175f, 0.0f, 0.674609f,
	    0.501375f, 0.702046f, 0.505721f,
	    0.084444f, 0.259892f, 0.961938f,
	    -0.512752f, 0.69378f, 0.505721f,
	    -0.221077f, 0.160622f, 0.961938f,
	    -0.818274f, -0.273267f, 0.505721f,
	    -0.221077f, -0.160622f, 0.961938f,
	    0.00703146f, -0.862668f, 0.505721f,
	    0.084444f, -0.259892f, 0.961938f,
	    0.822619f, -0.259892f, 0.505721f,
	    0.68164f, -0.69378f, -0.232454f,
	    0.959253f, -0.160622f, 0.232454f,
	    0.818274f, 0.273267f, -0.505721f,
	    0.959253f, 0.160622f, 0.232454f,
	    0.449186f, 0.862668f, 0.232454f,
	    -0.00703146f, 0.862668f, -0.505721f,
	    0.143665f, 0.961938f, 0.232454f,
	    -0.68164f, 0.69378f, 0.232454f,
	    -0.822619f, 0.259892f, -0.505721f,
	    -0.870463f, 0.433889f, 0.232454f,
	    -0.870463f, -0.433889f, 0.232454f,
	    -0.501375f, -0.702046f, -0.505721f,
	    -0.68164f, -0.69378f, 0.232454f,
	    0.143665f, -0.961938f, 0.232454f,
	    0.512752f, -0.69378f, -0.505721f,
	    0.221077f, -0.160622f, -0.961938f,
	    0.597196f, 0.433889f, -0.674609f,
	    -0.228109f, 0.702046f, -0.674609f,
	    -0.084444f, -0.259892f, -0.961938f,
	    -0.738175f, 0.0f, -0.674609f,
	    0.447214f, 0.525731f, 0.723607f,
	    0.361803f, 0.262866f, 0.894427f,
	    0.638197f, 0.262866f, 0.723607f,
	    -0.361803f, 0.587785f, 0.723607f,
	    -0.138197f, 0.425325f, 0.894427f,
	    -0.0527864f, 0.688191f, 0.723607f,
	    -0.67082f, -0.16246f, 0.723607f,
	    -0.447214f, 0.0f, 0.894427f,
	    -0.67082f, 0.16246f, 0.723607f,
	    -0.0527864f, -0.688191f, 0.723607f,
	    -0.138197f, -0.425325f, 0.894427f,
	    -0.361803f, -0.587785f, 0.723607f,
	    0.638197f, -0.262866f, 0.723607f,
	    0.361803f, -0.262866f, 0.894427f,
	    0.447214f, -0.525731f, 0.723607f,
	    0.809017f, -0.587785f, 2.34251e-008f,
	    0.861803f, -0.425325f, 0.276393f,
	    0.67082f, -0.688191f, 0.276393f,
	    0.947214f, 0.16246f, -0.276393f,
	    1.0f, 0.0f, 4.71253e-008f,
	    0.947214f, -0.16246f, -0.276393f,
	    0.67082f, 0.688191f, 0.276393f,
	    0.861803f, 0.425325f, 0.276393f,
	    0.809017f, 0.587785f, 2.34251e-008f,
	    0.138197f, 0.951057f, -0.276393f,
	    0.309017f, 0.951057f, -1.37573e-010f,
	    0.447214f, 0.850651f, -0.276393f,
	    -0.447214f, 0.850651f, 0.276393f,
	    -0.138197f, 0.951057f, 0.276393f,
	    -0.309017f, 0.951057f, 1.37573e-010f,
	    -0.861803f, 0.425325f, -0.276393f,
	    -0.809017f, 0.587785f, -2.34251e-008f,
	    -0.67082f, 0.688191f, -0.276393f,
	    -0.947214f, -0.16246f, 0.276393f,
	    -0.947214f, 0.16246f, 0.276393f,
	    -1.0f, 0.0f, -4.71253e-008f,
	    -0.67082f, -0.688191f, -0.276393f,
	    -0.809017f, -0.587785f, -2.34251e-008f,
	    -0.861803f, -0.425325f, -0.276393f,
	    -0.138197f, -0.951057f, 0.276393f,
	    -0.447214f, -0.850651f, 0.276393f,
	    -0.309017f, -0.951057f, 1.37573e-010f,
	    0.447214f, -0.850651f, -0.276393f,
	    0.309017f, -0.951057f, -1.37573e-010f,
	    0.138197f, -0.951057f, -0.276393f,
	    0.447214f,0.0f, -0.894427f,
	    0.67082f, 0.16246f, -0.723607f,
	    0.67082f, -0.16246f, -0.723607f,
	    0.0527864f, 0.688191f, -0.723607f,
	    0.361803f, 0.587785f, -0.723607f,
	    0.138197f, 0.425325f, -0.894427f,
	    0.138197f, -0.425325f, -0.894427f,
	    0.361803f, -0.587785f, -0.723607f,
	    0.0527864f, -0.688191f, -0.723607f,
	    -0.638197f, 0.262866f, -0.723607f,
	    -0.447214f, 0.525731f, -0.723607f,
	    -0.361803f, 0.262866f, -0.894427f,
	    -0.447214f, -0.525731f, -0.723607f,
	    -0.638197f, -0.262866f, -0.723607f,
	    -0.361803f, -0.262866f, -0.894427f,
	    0.137952f,0.0f, 0.990439f,
	    0.866811f, 0.1312f, 0.481067f,
	    0.254686f, 0.783843f, 0.566326f,
	    0.14308f, 0.864929f, 0.481067f,
	    -0.666777f, 0.484442f, 0.566326f,
	    -0.778382f, 0.403355f, 0.481067f,
	    -0.666777f, -0.484442f, 0.566326f,
	    -0.624147f, -0.615642f, 0.481067f,
	    0.254686f, -0.783843f, 0.566326f,
	    0.392638f, -0.783843f, 0.481067f,
	    0.366292f, -0.864929f, 0.343115f,
	    0.804729f, -0.484442f, -0.343115f,
	    0.778382f, -0.403355f, -0.481067f,
	    0.804729f, 0.484442f, -0.343115f,
	    0.709406f, 0.615642f, -0.343115f,
	    0.624147f, 0.615642f, -0.481067f,
	    -0.212056f, 0.915043f, -0.343115f,
	    -0.366292f, 0.864929f, -0.343115f,
	    -0.392638f, 0.783843f, -0.481067f,
	    -0.935787f, 0.0810863f, -0.343115f,
	    -0.935787f, -0.0810863f, -0.343115f,
	    -0.866811f, -0.1312f, -0.481067f,
	    -0.366292f, -0.864929f, -0.343115f,
	    -0.212056f, -0.915043f, -0.343115f,
	    -0.14308f, -0.864929f, -0.481067f,
	    0.666777f, -0.484442f, -0.566326f,
	    0.111606f, 0.0810863f, -0.990439f,
	    -0.0426296f, 0.1312f, -0.990439f,
	    -0.254686f, -0.783843f, -0.566326f,
	    -0.137952f,0.0f, -0.990439f,
	    0.638054f,0.0f, 0.769992f,
	    0.600525f, 0.606825f, 0.520705f,
	    0.124644f, 0.383614f, 0.915043f,
	    -0.391553f, 0.758652f, 0.520705f,
	    -0.326321f, 0.237086f, 0.915043f,
	    -0.842518f, -0.137952f, 0.520705f,
	    -0.326321f, -0.237086f, 0.915043f,
	    -0.129152f, -0.843911f, 0.520705f,
	    0.124644f, -0.383614f, 0.915043f,
	    0.762697f, -0.383614f, 0.520705f,
	    0.64084f, -0.758652f, -0.117349f,
	    0.964375f, -0.237086f, 0.117349f,
	    0.842518f, 0.137952f, -0.520705f,
	    0.964375f, 0.237086f, 0.117349f,
	    0.523491f, 0.843911f, 0.117349f,
	    0.129152f, 0.843911f, -0.520705f,
	    0.0725258f, 0.990439f, 0.117349f,
	    -0.64084f, 0.758652f, 0.117349f,
	    -0.762697f, 0.383614f, -0.520705f,
	    -0.919552f, 0.375039f, 0.117349f,
	    -0.919552f, -0.375039f, 0.117349f,
	    -0.600525f, -0.606825f, -0.520705f,
	    -0.64084f, -0.758652f, 0.117349f,
	    0.0725258f, -0.990439f, 0.117349f,
	    0.391553f, -0.758652f, -0.520705f,
	    0.326321f, -0.237086f, -0.915043f,
	    0.516196f, 0.375039f, -0.769992f,
	    -0.197169f, 0.606825f, -0.769992f,
	    -0.124644f, -0.383614f, -0.915043f,
	    -0.638054f,0.0f, -0.769992f,
	    0.308637f, 0.519258f, 0.79694f,
	    0.449299f, 0.133071f, 0.883415f,
	    0.671461f, 0.386187f, 0.632456f,
	    -0.39847f, 0.453991f, 0.79694f,
	    0.0122828f, 0.46843f, 0.883415f,
	    -0.159793f, 0.757935f, 0.632456f,
	    -0.554905f, -0.238677f, 0.79694f,
	    -0.441708f, 0.156434f, 0.883415f,
	    -0.770218f, 0.0822425f, 0.632456f,
	    0.0555203f, -0.601501f, 0.79694f,
	    -0.285273f, -0.371748f, 0.883415f,
	    -0.316228f, -0.707107f, 0.632456f,
	    0.589218f, -0.133071f, 0.79694f,
	    0.265399f, -0.386187f, 0.883415f,
	    0.574779f, -0.519258f, 0.632456f,
	    0.891007f, -0.453991f, 3.45473e-008f,
	    0.784658f, -0.46843f, 0.406061f,
	    0.637147f, -0.757935f, 0.139919f,
	    0.960966f, 0.238677f, -0.139919f,
	    0.987688f, -0.156434f, 4.65451e-008f,
	    0.910138f, -0.0822425f, -0.406061f,
	    0.687976f, 0.601501f, 0.406061f,
	    0.917729f, 0.371748f, 0.139919f,
	    0.707107f, 0.707107f, 1.17261e-008f,
	    0.0699596f, 0.987688f, -0.139919f,
	    0.45399f, 0.891007f, -2.02114e-010f,
	    0.359465f, 0.840178f, -0.406061f,
	    -0.359465f, 0.840178f, 0.406061f,
	    -0.0699596f, 0.987688f, 0.139919f,
	    -0.45399f, 0.891007f, 2.02114e-010f,
	    -0.917729f, 0.371748f, -0.139919f,
	    -0.707107f, 0.707107f, -1.17261e-008f,
	    -0.687976f, 0.601501f, -0.406061f,
	    -0.910138f, -0.0822425f, 0.406061f,
	    -0.960966f, 0.238677f, 0.139919f,
	    -0.987688f, -0.156434f, -4.65451e-008f,
	    -0.637147f, -0.757935f, -0.139919f,
	    -0.891007f, -0.453991f, -3.45473e-008f,
	    -0.784658f, -0.46843f, -0.406061f,
	    -0.203031f, -0.891007f, 0.406061f,
	    -0.52395f, -0.840178f, 0.139919f,
	    -0.156434f, -0.987688f, 6.96437e-011f,
	    0.52395f, -0.840178f, -0.139919f,
	    0.156434f, -0.987688f, -6.96437e-011f,
	    0.203031f, -0.891007f, -0.406061f,
	    0.441708f, 0.156434f, -0.883415f,
	    0.770218f, 0.0822425f, -0.632456f,
	    0.554905f, -0.238677f, -0.79694f,
	    0.159793f, 0.757935f, -0.632456f,
	    0.39847f, 0.453991f, -0.79694f,
	    -0.0122828f, 0.46843f, -0.883415f,
	    0.285273f, -0.371748f, -0.883415f,
	    0.316228f, -0.707107f, -0.632456f,
	    -0.0555203f, -0.601501f, -0.79694f,
	    -0.671461f, 0.386187f, -0.632456f,
	    -0.308637f, 0.519258f, -0.79694f,
	    -0.449299f, 0.133071f, -0.883415f,
	    -0.574779f, -0.519258f, -0.632456f,
	    -0.589218f, -0.133071f, -0.79694f,
	    -0.265399f, -0.386187f, -0.883415f,
	    0.403355f,0.0f, 0.915043f,
	    0.762697f, 0.383614f, 0.520705f,
	    0.197169f, 0.606825f, 0.769992f,
	    -0.129152f, 0.843911f, 0.520705f,
	    -0.516196f, 0.375039f, 0.769992f,
	    -0.842518f, 0.137952f, 0.520705f,
	    -0.516196f, -0.375039f, 0.769992f,
	    -0.391553f, -0.758652f, 0.520705f,
	    0.197169f, -0.606825f, 0.769992f,
	    0.600525f, -0.606825f, 0.520705f,
	    0.523491f, -0.843911f, 0.117349f,
	    0.919552f, -0.375039f, -0.117349f,
	    0.842518f, -0.137952f, -0.520705f,
	    0.919552f, 0.375039f, -0.117349f,
	    0.64084f, 0.758652f, -0.117349f,
	    0.391553f, 0.758652f, -0.520705f,
	    -0.0725258f, 0.990439f, -0.117349f,
	    -0.523491f, 0.843911f, -0.117349f,
	    -0.600525f, 0.606825f, -0.520705f,
	    -0.964375f, 0.237086f, -0.117349f,
	    -0.964375f, -0.237086f, -0.117349f,
	    -0.762697f, -0.383614f, -0.520705f,
	    -0.523491f, -0.843911f, -0.117349f,
	    -0.0725258f, -0.990439f, -0.117349f,
	    0.129152f, -0.843911f, -0.520705f,
	    0.516196f, -0.375039f, -0.769992f,
	    0.326321f, 0.237086f, -0.915043f,
	    -0.124644f, 0.383614f, -0.915043f,
	    -0.197169f, -0.606825f, -0.769992f,
	    -0.403355f,0.0f, -0.915043f,
	    0.824181f,0.0f, 0.566326f,
	    0.392638f, 0.783843f, 0.481067f,
	    0.0426296f, 0.1312f, 0.990439f,
	    -0.624147f, 0.615642f, 0.481067f,
	    -0.111606f, 0.0810863f, 0.990439f,
	    -0.778382f, -0.403355f, 0.481067f,
	    -0.111606f, -0.0810863f, 0.990439f,
	    0.14308f, -0.864929f, 0.481067f,
	    0.0426296f, -0.1312f, 0.990439f,
	    0.866811f, -0.1312f, 0.481067f,
	    0.709406f, -0.615642f, -0.343115f,
	    0.935787f, -0.0810863f, 0.343115f,
	    0.778382f, 0.403355f, -0.481067f,
	    0.935787f, 0.0810863f, 0.343115f,
	    0.366292f, 0.864929f, 0.343115f,
	    -0.14308f, 0.864929f, -0.481067f,
	    0.212056f, 0.915043f, 0.343115f,
	    -0.709406f, 0.615642f, 0.343115f,
	    -0.866811f, 0.1312f, -0.481067f,
	    -0.804729f, 0.484442f, 0.343115f,
	    -0.804729f, -0.484442f, 0.343115f,
	    -0.392638f, -0.783843f, -0.481067f,
	    -0.709406f, -0.615642f, 0.343115f,
	    0.212056f, -0.915043f, 0.343115f,
	    0.624147f, -0.615642f, -0.481067f,
	    0.111606f, -0.0810863f, -0.990439f,
	    0.666777f, 0.484442f, -0.566326f,
	    -0.254686f, 0.783843f, -0.566326f,
	    -0.0426296f, -0.1312f, -0.990439f,
	    -0.824181f,0.0f, -0.566326f,
	    0.574779f, 0.519258f, 0.632456f,
	    0.265399f, 0.386187f, 0.883415f,
	    0.589218f, 0.133071f, 0.79694f,
	    -0.316228f, 0.707107f, 0.632456f,
	    -0.285273f, 0.371748f, 0.883415f,
	    0.0555203f, 0.601501f, 0.79694f,
	    -0.770218f, -0.0822425f, 0.632456f,
	    -0.441708f, -0.156434f, 0.883415f,
	    -0.554905f, 0.238677f, 0.79694f,
	    -0.159793f, -0.757935f, 0.632456f,
	    0.0122828f, -0.46843f, 0.883415f,
	    -0.39847f, -0.453991f, 0.79694f,
	    0.671461f, -0.386187f, 0.632456f,
	    0.449299f, -0.133071f, 0.883415f,
	    0.308637f, -0.519258f, 0.79694f,
	    0.707107f, -0.707107f, 1.17261e-008f,
	    0.917729f, -0.371748f, 0.139919f,
	    0.687976f, -0.601501f, 0.406061f,
	    0.910138f, 0.0822425f, -0.406061f,
	    0.987688f, 0.156434f, 4.65451e-008f,
	    0.960966f, -0.238677f, -0.139919f,
	    0.637147f, 0.757935f, 0.139919f,
	    0.784658f, 0.46843f, 0.406061f,
	    0.891007f, 0.453991f, 3.45473e-008f,
	    0.203031f, 0.891007f, -0.406061f,
	    0.156434f, 0.987688f, -6.96437e-011f,
	    0.52395f, 0.840178f, -0.139919f,
	    -0.52395f, 0.840178f, 0.139919f,
	    -0.203031f, 0.891007f, 0.406061f,
	    -0.156434f, 0.987688f, 6.96437e-011f,
	    -0.784658f, 0.46843f, -0.406061f,
	    -0.891007f, 0.453991f, -3.45473e-008f,
	    -0.637147f, 0.757935f, -0.139919f,
	    -0.960966f, -0.238677f, 0.139919f,
	    -0.910138f, 0.0822425f, 0.406061f,
	    -0.987688f, 0.156434f, -4.65451e-008f,
	    -0.687976f, -0.601501f, -0.406061f,
	    -0.707107f, -0.707107f, -1.17261e-008f,
	    -0.917729f, -0.371748f, -0.139919f,
	    -0.0699596f, -0.987688f, 0.139919f,
	    -0.359465f, -0.840178f, 0.406061f,
	    -0.45399f, -0.891007f, 2.02114e-010f,
	    0.359465f, -0.840178f, -0.406061f,
	    0.45399f, -0.891007f, -2.02114e-010f,
	    0.0699596f, -0.987688f, -0.139919f,
	    0.441708f, -0.156434f, -0.883415f,
	    0.554905f, 0.238677f, -0.79694f,
	    0.770218f, -0.0822425f, -0.632456f,
	    -0.0555203f, 0.601501f, -0.79694f,
	    0.316228f, 0.707107f, -0.632456f,
	    0.285273f, 0.371748f, -0.883415f,
	    -0.0122828f, -0.46843f, -0.883415f,
	    0.39847f, -0.453991f, -0.79694f,
	    0.159793f, -0.757935f, -0.632456f,
	    -0.589218f, 0.133071f, -0.79694f,
	    -0.574779f, 0.519258f, -0.632456f,
	    -0.265399f, 0.386187f, -0.883415f,
	    -0.308637f, -0.519258f, -0.79694f,
	    -0.671461f, -0.386187f, -0.632456f,
	    -0.449299f, -0.133071f, -0.883415f,
	    0.409955f, 0.399607f, 0.819909f,
	    0.506732f, 0.266405f, 0.819909f,
	    0.550012f, 0.399607f, 0.733349f,
	    -0.253366f, 0.513375f, 0.819909f,
	    -0.0967772f, 0.564254f, 0.819909f,
	    -0.210086f, 0.646578f, 0.733349f,
	    -0.566543f, -0.0823236f, 0.819909f,
	    -0.566543f, 0.0823236f, 0.819909f,
	    -0.679852f,0.0f, 0.733349f,
	    -0.0967772f, -0.564254f, 0.819909f,
	    -0.253366f, -0.513375f, 0.819909f,
	    -0.210086f, -0.646578f, 0.733349f,
	    0.506732f, -0.266405f, 0.819909f,
	    0.409955f, -0.399607f, 0.819909f,
	    0.550012f, -0.399607f, 0.733349f,
	    0.846658f, -0.513375f, 0.140057f,
	    0.776629f, -0.564254f, 0.280115f,
	    0.749881f, -0.646578f, 0.140057f,
	    0.986715f, 0.0823236f, -0.140057f,
	    0.986715f, -0.0823236f, -0.140057f,
	    0.959967f,0.0f, -0.280114f,
	    0.776629f, 0.564254f, 0.280115f,
	    0.846658f, 0.513375f, 0.140057f,
	    0.749881f, 0.646578f, 0.140057f,
	    0.226617f, 0.963861f, -0.140057f,
	    0.383206f, 0.912982f, -0.140057f,
	    0.296646f, 0.912982f, -0.280114f,
	    -0.296646f, 0.912982f, 0.280114f,
	    -0.226617f, 0.963861f, 0.140057f,
	    -0.383206f, 0.912982f, 0.140057f,
	    -0.846658f, 0.513375f, -0.140057f,
	    -0.749881f, 0.646578f, -0.140057f,
	    -0.776629f, 0.564254f, -0.280115f,
	    -0.959967f,0.0f, 0.280114f,
	    -0.986715f, 0.0823236f, 0.140057f,
	    -0.986715f, -0.0823236f, 0.140057f,
	    -0.749881f, -0.646578f, -0.140057f,
	    -0.846658f, -0.513375f, -0.140057f,
	    -0.776629f, -0.564254f, -0.280115f,
	    -0.296646f, -0.912982f, 0.280114f,
	    -0.383206f, -0.912982f, 0.140057f,
	    -0.226617f, -0.963861f, 0.140057f,
	    0.383206f, -0.912982f, -0.140057f,
	    0.226617f, -0.963861f, -0.140057f,
	    0.296646f, -0.912982f, -0.280114f,
	    0.566543f, 0.0823236f, -0.819909f,
	    0.679852f,0.0f, -0.733349f,
	    0.566543f, -0.0823236f, -0.819909f,
	    0.210086f, 0.646578f, -0.733349f,
	    0.253366f, 0.513375f, -0.819909f,
	    0.0967772f, 0.564254f, -0.819909f,
	    0.253366f, -0.513375f, -0.819909f,
	    0.210086f, -0.646578f, -0.733349f,
	    0.0967772f, -0.564254f, -0.819909f,
	    -0.550012f, 0.399607f, -0.733349f,
	    -0.409955f, 0.399607f, -0.819909f,
	    -0.506732f, 0.266405f, -0.819909f,
	    -0.550012f, -0.399607f, -0.733349f,
	    -0.506732f, -0.266405f, -0.819909f,
	    -0.409955f, -0.399607f, -0.819909f,
	    0.36954f, 0.711282f, 0.597928f,
	    0.341154f, 0.62024f, 0.70634f,
	    0.479201f, 0.62024f, 0.621023f,
	    0.181208f, 0.131655f, 0.974592f,
	    0.32082f, 0.132792f, 0.937785f,
	    0.225432f, 0.264083f, 0.937785f,
	    0.790663f, 0.131655f, 0.597928f,
	    0.737964f, 0.264083f, 0.621023f,
	    0.695305f, 0.132792f, 0.70634f,
	    -0.562275f, 0.571252f, 0.597928f,
	    -0.48446f, 0.516122f, 0.70634f,
	    -0.441802f, 0.647412f, 0.621023f,
	    -0.0692153f, 0.213023f, 0.974592f,
	    -0.0271543f, 0.346153f, 0.937785f,
	    -0.181495f, 0.296005f, 0.937785f,
	    0.119117f, 0.792649f, 0.597928f,
	    -0.0231141f, 0.783452f, 0.621023f,
	    0.088568f, 0.70231f, 0.70634f,
	    -0.717045f, -0.358229f, 0.597928f,
	    -0.640567f, -0.301259f, 0.70634f,
	    -0.75225f, -0.220117f, 0.621023f,
	    -0.223985f,0.0f, 0.974592f,
	    -0.337602f, 0.0811419f, 0.937785f,
	    -0.337602f, -0.0811419f, 0.937785f,
	    -0.717045f, 0.358229f, 0.597928f,
	    -0.75225f, 0.220117f, 0.621023f,
	    -0.640567f, 0.301259f, 0.70634f,
	    0.119117f, -0.792649f, 0.597928f,
	    0.088568f, -0.70231f, 0.70634f,
	    -0.0231141f, -0.783452f, 0.621023f,
	    -0.0692153f, -0.213023f, 0.974592f,
	    -0.181495f, -0.296005f, 0.937785f,
	    -0.0271543f, -0.346153f, 0.937785f,
	    -0.562275f, -0.571252f, 0.597928f,
	    -0.441802f, -0.647412f, 0.621023f,
	    -0.48446f, -0.516122f, 0.70634f,
	    0.790663f, -0.131655f, 0.597928f,
	    0.695305f, -0.132792f, 0.70634f,
	    0.737964f, -0.264083f, 0.621023f,
	    0.181208f, -0.131655f, 0.974592f,
	    0.225432f, -0.264083f, 0.937785f,
	    0.32082f, -0.132792f, 0.937785f,
	    0.36954f, -0.711282f, 0.597928f,
	    0.479201f, -0.62024f, 0.621023f,
	    0.341154f, -0.62024f, 0.70634f,
	    0.78626f, -0.571252f, -0.235512f,
	    0.848427f, -0.516122f, -0.11743f,
	    0.753039f, -0.647412f, -0.11743f,
	    0.902656f, -0.213023f, 0.373943f,
	    0.850924f, -0.346153f, 0.395103f,
	    0.919948f, -0.296005f, 0.257056f,
	    0.481533f, -0.792649f, 0.373943f,
	    0.565797f, -0.783452f, 0.257056f,
	    0.592161f, -0.70231f, 0.395103f,
	    0.855476f, 0.358229f, -0.373943f,
	    0.91824f, 0.301259f, -0.257056f,
	    0.891876f, 0.220117f, -0.395103f,
	    0.971871f,0.0f, 0.235512f,
	    0.989761f, -0.0811419f, 0.11743f,
	    0.989761f, 0.0811419f, 0.11743f,
	    0.855476f, -0.358229f, -0.373943f,
	    0.891876f, -0.220117f, -0.395103f,
	    0.91824f, -0.301259f, -0.257056f,
	    0.481533f, 0.792649f, 0.373943f,
	    0.592161f, 0.70231f, 0.395103f,
	    0.565797f, 0.783452f, 0.257056f,
	    0.902656f, 0.213023f, 0.373943f,
	    0.919948f, 0.296005f, 0.257056f,
	    0.850924f, 0.346153f, 0.395103f,
	    0.78626f, 0.571252f, -0.235512f,
	    0.753039f, 0.647412f, -0.11743f,
	    0.848427f, 0.516122f, -0.11743f,
	    -0.0763393f, 0.924305f, -0.373943f,
	    -0.00276234f, 0.966393f, -0.257056f,
	    0.066261f, 0.916244f, -0.395103f,
	    0.300325f, 0.924305f, 0.235512f,
	    0.383023f, 0.916244f, 0.11743f,
	    0.228682f, 0.966393f, 0.11743f,
	    0.605052f, 0.702907f, -0.373943f,
	    0.484949f, 0.780204f, -0.395103f,
	    0.570266f, 0.780204f, -0.257056f,
	    -0.605052f, 0.702907f, 0.373943f,
	    -0.484949f, 0.780204f, 0.395103f,
	    -0.570266f, 0.780204f, 0.257056f,
	    0.0763393f, 0.924305f, 0.373943f,
	    0.00276234f, 0.966393f, 0.257056f,
	    -0.066261f, 0.916244f, 0.395103f,
	    -0.300325f, 0.924305f, -0.235512f,
	    -0.383023f, 0.916244f, -0.11743f,
	    -0.228682f, 0.966393f, -0.11743f,
	    -0.902656f, 0.213023f, -0.373943f,
	    -0.919948f, 0.296005f, -0.257056f,
	    -0.850924f, 0.346153f, -0.395103f,
	    -0.78626f, 0.571252f, 0.235512f,
	    -0.753039f, 0.647412f, 0.11743f,
	    -0.848427f, 0.516122f, 0.11743f,
	    -0.481533f, 0.792649f, -0.373943f,
	    -0.592161f, 0.70231f, -0.395103f,
	    -0.565797f, 0.783452f, -0.257056f,
	    -0.855476f, -0.358229f, 0.373943f,
	    -0.891876f, -0.220117f, 0.395103f,
	    -0.91824f, -0.301259f, 0.257056f,
	    -0.855476f, 0.358229f, 0.373943f,
	    -0.91824f, 0.301259f, 0.257056f,
	    -0.891876f, 0.220117f, 0.395103f,
	    -0.971871f,0.0f, -0.235512f,
	    -0.989761f, -0.0811419f, -0.11743f,
	    -0.989761f, 0.0811419f, -0.11743f,
	    -0.481533f, -0.792649f, -0.373943f,
	    -0.565797f, -0.783452f, -0.257056f,
	    -0.592161f, -0.70231f, -0.395103f,
	    -0.78626f, -0.571252f, 0.235512f,
	    -0.848427f, -0.516122f, 0.11743f,
	    -0.753039f, -0.647412f, 0.11743f,
	    -0.902656f, -0.213023f, -0.373943f,
	    -0.850924f, -0.346153f, -0.395103f,
	    -0.919948f, -0.296005f, -0.257056f,
	    0.0763393f, -0.924305f, 0.373943f,
	    -0.066261f, -0.916244f, 0.395103f,
	    0.00276234f, -0.966393f, 0.257056f,
	    -0.605052f, -0.702907f, 0.373943f,
	    -0.570266f, -0.780204f, 0.257056f,
	    -0.484949f, -0.780204f, 0.395103f,
	    -0.300325f, -0.924305f, -0.235512f,
	    -0.228682f, -0.966393f, -0.11743f,
	    -0.383023f, -0.916244f, -0.11743f,
	    0.605052f, -0.702907f, -0.373943f,
	    0.570266f, -0.780204f, -0.257056f,
	    0.484949f, -0.780204f, -0.395103f,
	    0.300325f, -0.924305f, 0.235512f,
	    0.228682f, -0.966393f, 0.11743f,
	    0.383023f, -0.916244f, 0.11743f,
	    -0.0763393f, -0.924305f, -0.373943f,
	    0.066261f, -0.916244f, -0.395103f,
	    -0.00276234f, -0.966393f, -0.257056f,
	    0.223985f,0.0f, -0.974592f,
	    0.337602f, 0.0811419f, -0.937785f,
	    0.337602f, -0.0811419f, -0.937785f,
	    0.717045f, 0.358229f, -0.597928f,
	    0.75225f, 0.220117f, -0.621023f,
	    0.640567f, 0.301259f, -0.70634f,
	    0.717045f, -0.358229f, -0.597928f,
	    0.640567f, -0.301259f, -0.70634f,
	    0.75225f, -0.220117f, -0.621023f,
	    -0.119117f, 0.792649f, -0.597928f,
	    0.0231141f, 0.783452f, -0.621023f,
	    -0.088568f, 0.70231f, -0.70634f,
	    0.562275f, 0.571252f, -0.597928f,
	    0.48446f, 0.516122f, -0.70634f,
	    0.441802f, 0.647412f, -0.621023f,
	    0.0692153f, 0.213023f, -0.974592f,
	    0.0271543f, 0.346153f, -0.937785f,
	    0.181495f, 0.296005f, -0.937785f,
	    0.0692153f, -0.213023f, -0.974592f,
	    0.181495f, -0.296005f, -0.937785f,
	    0.0271543f, -0.346153f, -0.937785f,
	    0.562275f, -0.571252f, -0.597928f,
	    0.441802f, -0.647412f, -0.621023f,
	    0.48446f, -0.516122f, -0.70634f,
	    -0.119117f, -0.792649f, -0.597928f,
	    -0.088568f, -0.70231f, -0.70634f,
	    0.0231141f, -0.783452f, -0.621023f,
	    -0.790663f, 0.131655f, -0.597928f,
	    -0.737964f, 0.264083f, -0.621023f,
	    -0.695305f, 0.132792f, -0.70634f,
	    -0.36954f, 0.711282f, -0.597928f,
	    -0.341154f, 0.62024f, -0.70634f,
	    -0.479201f, 0.62024f, -0.621023f,
	    -0.181208f, 0.131655f, -0.974592f,
	    -0.32082f, 0.132792f, -0.937785f,
	    -0.225432f, 0.264083f, -0.937785f,
	    -0.36954f, -0.711282f, -0.597928f,
	    -0.479201f, -0.62024f, -0.621023f,
	    -0.341154f, -0.62024f, -0.70634f,
	    -0.790663f, -0.131655f, -0.597928f,
	    -0.695305f, -0.132792f, -0.70634f,
	    -0.737964f, -0.264083f, -0.621023f,
	    -0.181208f, -0.131655f, -0.974592f,
	    -0.225432f, -0.264083f, -0.937785f,
	    -0.32082f, -0.132792f, -0.937785f
	};

	static GLushort SPHERE_MODEL_TRIANGLES[SPHERE_MODEL_NB_TRIANGLES*3] = {
	    403, 404, 402,
	    406, 407, 405,
	    409, 410, 408,
	    412, 413, 411,
	    415, 416, 414,
	    418, 419, 417,
	    421, 422, 420,
	    424, 425, 423,
	    427, 428, 426,
	    430, 431, 429,
	    433, 434, 432,
	    436, 437, 435,
	    439, 440, 438,
	    442, 443, 441,
	    445, 446, 444,
	    448, 449, 447,
	    451, 452, 450,
	    454, 455, 453,
	    457, 458, 456,
	    460, 461, 459,
	    463, 464, 462,
	    466, 467, 465,
	    469, 470, 468,
	    472, 473, 471,
	    475, 476, 474,
	    478, 479, 477,
	    481, 482, 480,
	    484, 485, 483,
	    487, 488, 486,
	    490, 491, 489,
	    493, 494, 492,
	    496, 497, 495,
	    499, 500, 498,
	    502, 503, 501,
	    505, 506, 504,
	    508, 509, 507,
	    511, 512, 510,
	    514, 515, 513,
	    517, 518, 516,
	    520, 521, 519,
	    523, 524, 522,
	    526, 527, 525,
	    529, 530, 528,
	    532, 533, 531,
	    535, 536, 534,
	    538, 539, 537,
	    541, 542, 540,
	    544, 545, 543,
	    547, 548, 546,
	    550, 551, 549,
	    553, 554, 552,
	    556, 557, 555,
	    559, 560, 558,
	    562, 563, 561,
	    565, 566, 564,
	    568, 569, 567,
	    571, 572, 570,
	    574, 575, 573,
	    577, 578, 576,
	    580, 581, 579,
	    583, 584, 582,
	    586, 587, 585,
	    589, 590, 588,
	    592, 593, 591,
	    595, 596, 594,
	    598, 599, 597,
	    601, 602, 600,
	    604, 605, 603,
	    607, 608, 606,
	    610, 611, 609,
	    613, 614, 612,
	    616, 617, 615,
	    619, 620, 618,
	    622, 623, 621,
	    625, 626, 624,
	    628, 629, 627,
	    631, 632, 630,
	    634, 635, 633,
	    637, 638, 636,
	    640, 641, 639,
	    343, 402, 222,
	    344, 403, 223,
	    342, 404, 224,
	    346, 405, 225,
	    347, 406, 226,
	    345, 407, 227,
	    349, 408, 228,
	    350, 409, 229,
	    348, 410, 230,
	    352, 411, 231,
	    353, 412, 232,
	    351, 413, 233,
	    355, 414, 234,
	    356, 415, 235,
	    354, 416, 236,
	    358, 417, 237,
	    359, 418, 238,
	    357, 419, 239,
	    361, 420, 240,
	    362, 421, 241,
	    360, 422, 242,
	    364, 423, 243,
	    365, 424, 244,
	    363, 425, 245,
	    367, 426, 246,
	    368, 427, 247,
	    366, 428, 248,
	    370, 429, 249,
	    371, 430, 250,
	    369, 431, 251,
	    373, 432, 252,
	    374, 433, 253,
	    372, 434, 254,
	    376, 435, 255,
	    377, 436, 256,
	    375, 437, 257,
	    379, 438, 258,
	    380, 439, 259,
	    378, 440, 260,
	    382, 441, 261,
	    383, 442, 262,
	    381, 443, 263,
	    385, 444, 264,
	    386, 445, 265,
	    384, 446, 266,
	    388, 447, 267,
	    389, 448, 268,
	    387, 449, 269,
	    391, 450, 270,
	    392, 451, 271,
	    390, 452, 272,
	    394, 453, 273,
	    395, 454, 274,
	    393, 455, 275,
	    397, 456, 276,
	    398, 457, 277,
	    396, 458, 278,
	    400, 459, 279,
	    401, 460, 280,
	    399, 461, 281,
	    164, 462, 313,
	    222, 463, 284,
	    193, 464, 342,
	    162, 465, 314,
	    223, 466, 282,
	    194, 467, 343,
	    163, 468, 312,
	    224, 469, 283,
	    192, 470, 344,
	    166, 471, 315,
	    225, 472, 286,
	    195, 473, 345,
	    314, 474, 316,
	    226, 475, 194,
	    196, 476, 346,
	    165, 477, 164,
	    227, 478, 285,
	    284, 479, 347,
	    168, 480, 317,
	    228, 481, 288,
	    197, 482, 348,
	    316, 483, 318,
	    229, 484, 196,
	    198, 485, 349,
	    167, 486, 166,
	    230, 487, 287,
	    286, 488, 350,
	    170, 489, 319,
	    231, 490, 290,
	    199, 491, 351,
	    318, 492, 320,
	    232, 493, 198,
	    200, 494, 352,
	    169, 495, 168,
	    233, 496, 289,
	    288, 497, 353,
	    312, 498, 321,
	    234, 499, 192,
	    201, 500, 354,
	    320, 501, 162,
	    235, 502, 200,
	    282, 503, 355,
	    171, 504, 170,
	    236, 505, 291,
	    290, 506, 356,
	    173, 507, 322,
	    237, 508, 293,
	    202, 509, 357,
	    321, 510, 323,
	    238, 511, 201,
	    203, 512, 358,
	    172, 513, 171,
	    239, 514, 292,
	    291, 515, 359,
	    175, 516, 324,
	    240, 517, 295,
	    204, 518, 360,
	    323, 519, 325,
	    241, 520, 203,
	    205, 521, 361,
	    174, 522, 173,
	    242, 523, 294,
	    293, 524, 362,
	    313, 525, 326,
	    243, 526, 193,
	    206, 527, 363,
	    325, 528, 163,
	    244, 529, 205,
	    283, 530, 364,
	    176, 531, 175,
	    245, 532, 296,
	    295, 533, 365,
	    178, 534, 327,
	    246, 535, 298,
	    207, 536, 366,
	    326, 537, 328,
	    247, 538, 206,
	    208, 539, 367,
	    177, 540, 176,
	    248, 541, 297,
	    296, 542, 368,
	    315, 543, 329,
	    249, 544, 195,
	    209, 545, 369,
	    328, 546, 165,
	    250, 547, 208,
	    285, 548, 370,
	    179, 549, 178,
	    251, 550, 299,
	    298, 551, 371,
	    181, 552, 330,
	    252, 553, 301,
	    210, 554, 372,
	    329, 555, 331,
	    253, 556, 209,
	    211, 557, 373,
	    180, 558, 179,
	    254, 559, 300,
	    299, 560, 374,
	    317, 561, 332,
	    255, 562, 197,
	    212, 563, 375,
	    331, 564, 167,
	    256, 565, 211,
	    287, 566, 376,
	    182, 567, 181,
	    257, 568, 302,
	    301, 569, 377,
	    184, 570, 333,
	    258, 571, 304,
	    213, 572, 378,
	    332, 573, 334,
	    259, 574, 212,
	    214, 575, 379,
	    183, 576, 182,
	    260, 577, 303,
	    302, 578, 380,
	    319, 579, 335,
	    261, 580, 199,
	    215, 581, 381,
	    334, 582, 169,
	    262, 583, 214,
	    289, 584, 382,
	    185, 585, 184,
	    263, 586, 305,
	    304, 587, 383,
	    322, 588, 336,
	    264, 589, 202,
	    216, 590, 384,
	    335, 591, 172,
	    265, 592, 215,
	    292, 593, 385,
	    186, 594, 185,
	    266, 595, 306,
	    305, 596, 386,
	    188, 597, 337,
	    267, 598, 308,
	    217, 599, 387,
	    324, 600, 338,
	    268, 601, 204,
	    218, 602, 388,
	    187, 603, 174,
	    269, 604, 307,
	    294, 605, 389,
	    327, 606, 339,
	    270, 607, 207,
	    219, 608, 390,
	    338, 609, 177,
	    271, 610, 218,
	    297, 611, 391,
	    189, 612, 188,
	    272, 613, 309,
	    308, 614, 392,
	    337, 615, 340,
	    273, 616, 217,
	    220, 617, 393,
	    336, 618, 187,
	    274, 619, 216,
	    307, 620, 394,
	    190, 621, 186,
	    275, 622, 310,
	    306, 623, 395,
	    330, 624, 341,
	    276, 625, 210,
	    221, 626, 396,
	    339, 627, 180,
	    277, 628, 219,
	    300, 629, 397,
	    191, 630, 189,
	    278, 631, 311,
	    309, 632, 398,
	    333, 633, 190,
	    279, 634, 213,
	    310, 635, 399,
	    341, 636, 183,
	    280, 637, 221,
	    303, 638, 400,
	    340, 639, 191,
	    281, 640, 220,
	    311, 641, 401,
	    103, 403, 402,
	    104, 404, 403,
	    102, 402, 404,
	    106, 406, 405,
	    107, 407, 406,
	    105, 405, 407,
	    109, 409, 408,
	    110, 410, 409,
	    108, 408, 410,
	    112, 412, 411,
	    113, 413, 412,
	    111, 411, 413,
	    115, 415, 414,
	    116, 416, 415,
	    114, 414, 416,
	    118, 418, 417,
	    119, 419, 418,
	    117, 417, 419,
	    121, 421, 420,
	    122, 422, 421,
	    120, 420, 422,
	    124, 424, 423,
	    125, 425, 424,
	    123, 423, 425,
	    127, 427, 426,
	    128, 428, 427,
	    126, 426, 428,
	    130, 430, 429,
	    131, 431, 430,
	    129, 429, 431,
	    133, 433, 432,
	    134, 434, 433,
	    132, 432, 434,
	    136, 436, 435,
	    137, 437, 436,
	    135, 435, 437,
	    139, 439, 438,
	    140, 440, 439,
	    138, 438, 440,
	    142, 442, 441,
	    143, 443, 442,
	    141, 441, 443,
	    145, 445, 444,
	    146, 446, 445,
	    144, 444, 446,
	    148, 448, 447,
	    149, 449, 448,
	    147, 447, 449,
	    151, 451, 450,
	    152, 452, 451,
	    150, 450, 452,
	    154, 454, 453,
	    155, 455, 454,
	    153, 453, 455,
	    157, 457, 456,
	    158, 458, 457,
	    156, 456, 458,
	    160, 460, 459,
	    161, 461, 460,
	    159, 459, 461,
	    44, 463, 462,
	    102, 464, 463,
	    73, 462, 464,
	    42, 466, 465,
	    103, 467, 466,
	    74, 465, 467,
	    43, 469, 468,
	    104, 470, 469,
	    72, 468, 470,
	    46, 472, 471,
	    105, 473, 472,
	    75, 471, 473,
	    74, 475, 474,
	    106, 476, 475,
	    76, 474, 476,
	    45, 478, 477,
	    107, 479, 478,
	    44, 477, 479,
	    48, 481, 480,
	    108, 482, 481,
	    77, 480, 482,
	    76, 484, 483,
	    109, 485, 484,
	    78, 483, 485,
	    47, 487, 486,
	    110, 488, 487,
	    46, 486, 488,
	    50, 490, 489,
	    111, 491, 490,
	    79, 489, 491,
	    78, 493, 492,
	    112, 494, 493,
	    80, 492, 494,
	    49, 496, 495,
	    113, 497, 496,
	    48, 495, 497,
	    72, 499, 498,
	    114, 500, 499,
	    81, 498, 500,
	    80, 502, 501,
	    115, 503, 502,
	    42, 501, 503,
	    51, 505, 504,
	    116, 506, 505,
	    50, 504, 506,
	    53, 508, 507,
	    117, 509, 508,
	    82, 507, 509,
	    81, 511, 510,
	    118, 512, 511,
	    83, 510, 512,
	    52, 514, 513,
	    119, 515, 514,
	    51, 513, 515,
	    55, 517, 516,
	    120, 518, 517,
	    84, 516, 518,
	    83, 520, 519,
	    121, 521, 520,
	    85, 519, 521,
	    54, 523, 522,
	    122, 524, 523,
	    53, 522, 524,
	    73, 526, 525,
	    123, 527, 526,
	    86, 525, 527,
	    85, 529, 528,
	    124, 530, 529,
	    43, 528, 530,
	    56, 532, 531,
	    125, 533, 532,
	    55, 531, 533,
	    58, 535, 534,
	    126, 536, 535,
	    87, 534, 536,
	    86, 538, 537,
	    127, 539, 538,
	    88, 537, 539,
	    57, 541, 540,
	    128, 542, 541,
	    56, 540, 542,
	    75, 544, 543,
	    129, 545, 544,
	    89, 543, 545,
	    88, 547, 546,
	    130, 548, 547,
	    45, 546, 548,
	    59, 550, 549,
	    131, 551, 550,
	    58, 549, 551,
	    61, 553, 552,
	    132, 554, 553,
	    90, 552, 554,
	    89, 556, 555,
	    133, 557, 556,
	    91, 555, 557,
	    60, 559, 558,
	    134, 560, 559,
	    59, 558, 560,
	    77, 562, 561,
	    135, 563, 562,
	    92, 561, 563,
	    91, 565, 564,
	    136, 566, 565,
	    47, 564, 566,
	    62, 568, 567,
	    137, 569, 568,
	    61, 567, 569,
	    64, 571, 570,
	    138, 572, 571,
	    93, 570, 572,
	    92, 574, 573,
	    139, 575, 574,
	    94, 573, 575,
	    63, 577, 576,
	    140, 578, 577,
	    62, 576, 578,
	    79, 580, 579,
	    141, 581, 580,
	    95, 579, 581,
	    94, 583, 582,
	    142, 584, 583,
	    49, 582, 584,
	    65, 586, 585,
	    143, 587, 586,
	    64, 585, 587,
	    82, 589, 588,
	    144, 590, 589,
	    96, 588, 590,
	    95, 592, 591,
	    145, 593, 592,
	    52, 591, 593,
	    66, 595, 594,
	    146, 596, 595,
	    65, 594, 596,
	    68, 598, 597,
	    147, 599, 598,
	    97, 597, 599,
	    84, 601, 600,
	    148, 602, 601,
	    98, 600, 602,
	    67, 604, 603,
	    149, 605, 604,
	    54, 603, 605,
	    87, 607, 606,
	    150, 608, 607,
	    99, 606, 608,
	    98, 610, 609,
	    151, 611, 610,
	    57, 609, 611,
	    69, 613, 612,
	    152, 614, 613,
	    68, 612, 614,
	    97, 616, 615,
	    153, 617, 616,
	    100, 615, 617,
	    96, 619, 618,
	    154, 620, 619,
	    67, 618, 620,
	    70, 622, 621,
	    155, 623, 622,
	    66, 621, 623,
	    90, 625, 624,
	    156, 626, 625,
	    101, 624, 626,
	    99, 628, 627,
	    157, 629, 628,
	    60, 627, 629,
	    71, 631, 630,
	    158, 632, 631,
	    69, 630, 632,
	    93, 634, 633,
	    159, 635, 634,
	    70, 633, 635,
	    101, 637, 636,
	    160, 638, 637,
	    63, 636, 638,
	    100, 640, 639,
	    161, 641, 640,
	    71, 639, 641,
	    14, 343, 222,
	    103, 402, 343,
	    102, 222, 402,
	    12, 344, 223,
	    104, 403, 344,
	    103, 223, 403,
	    13, 342, 224,
	    102, 404, 342,
	    104, 224, 404,
	    16, 346, 225,
	    106, 405, 346,
	    105, 225, 405,
	    14, 347, 226,
	    107, 406, 347,
	    106, 226, 406,
	    15, 345, 227,
	    105, 407, 345,
	    107, 227, 407,
	    18, 349, 228,
	    109, 408, 349,
	    108, 228, 408,
	    16, 350, 229,
	    110, 409, 350,
	    109, 229, 409,
	    17, 348, 230,
	    108, 410, 348,
	    110, 230, 410,
	    20, 352, 231,
	    112, 411, 352,
	    111, 231, 411,
	    18, 353, 232,
	    113, 412, 353,
	    112, 232, 412,
	    19, 351, 233,
	    111, 413, 351,
	    113, 233, 413,
	    12, 355, 234,
	    115, 414, 355,
	    114, 234, 414,
	    20, 356, 235,
	    116, 415, 356,
	    115, 235, 415,
	    21, 354, 236,
	    114, 416, 354,
	    116, 236, 416,
	    23, 358, 237,
	    118, 417, 358,
	    117, 237, 417,
	    21, 359, 238,
	    119, 418, 359,
	    118, 238, 418,
	    22, 357, 239,
	    117, 419, 357,
	    119, 239, 419,
	    25, 361, 240,
	    121, 420, 361,
	    120, 240, 420,
	    23, 362, 241,
	    122, 421, 362,
	    121, 241, 421,
	    24, 360, 242,
	    120, 422, 360,
	    122, 242, 422,
	    13, 364, 243,
	    124, 423, 364,
	    123, 243, 423,
	    25, 365, 244,
	    125, 424, 365,
	    124, 244, 424,
	    26, 363, 245,
	    123, 425, 363,
	    125, 245, 425,
	    28, 367, 246,
	    127, 426, 367,
	    126, 246, 426,
	    26, 368, 247,
	    128, 427, 368,
	    127, 247, 427,
	    27, 366, 248,
	    126, 428, 366,
	    128, 248, 428,
	    15, 370, 249,
	    130, 429, 370,
	    129, 249, 429,
	    28, 371, 250,
	    131, 430, 371,
	    130, 250, 430,
	    29, 369, 251,
	    129, 431, 369,
	    131, 251, 431,
	    31, 373, 252,
	    133, 432, 373,
	    132, 252, 432,
	    29, 374, 253,
	    134, 433, 374,
	    133, 253, 433,
	    30, 372, 254,
	    132, 434, 372,
	    134, 254, 434,
	    17, 376, 255,
	    136, 435, 376,
	    135, 255, 435,
	    31, 377, 256,
	    137, 436, 377,
	    136, 256, 436,
	    32, 375, 257,
	    135, 437, 375,
	    137, 257, 437,
	    34, 379, 258,
	    139, 438, 379,
	    138, 258, 438,
	    32, 380, 259,
	    140, 439, 380,
	    139, 259, 439,
	    33, 378, 260,
	    138, 440, 378,
	    140, 260, 440,
	    19, 382, 261,
	    142, 441, 382,
	    141, 261, 441,
	    34, 383, 262,
	    143, 442, 383,
	    142, 262, 442,
	    35, 381, 263,
	    141, 443, 381,
	    143, 263, 443,
	    22, 385, 264,
	    145, 444, 385,
	    144, 264, 444,
	    35, 386, 265,
	    146, 445, 386,
	    145, 265, 445,
	    36, 384, 266,
	    144, 446, 384,
	    146, 266, 446,
	    38, 388, 267,
	    148, 447, 388,
	    147, 267, 447,
	    24, 389, 268,
	    149, 448, 389,
	    148, 268, 448,
	    37, 387, 269,
	    147, 449, 387,
	    149, 269, 449,
	    27, 391, 270,
	    151, 450, 391,
	    150, 270, 450,
	    38, 392, 271,
	    152, 451, 392,
	    151, 271, 451,
	    39, 390, 272,
	    150, 452, 390,
	    152, 272, 452,
	    37, 394, 273,
	    154, 453, 394,
	    153, 273, 453,
	    36, 395, 274,
	    155, 454, 395,
	    154, 274, 454,
	    40, 393, 275,
	    153, 455, 393,
	    155, 275, 455,
	    30, 397, 276,
	    157, 456, 397,
	    156, 276, 456,
	    39, 398, 277,
	    158, 457, 398,
	    157, 277, 457,
	    41, 396, 278,
	    156, 458, 396,
	    158, 278, 458,
	    33, 400, 279,
	    160, 459, 400,
	    159, 279, 459,
	    41, 401, 280,
	    161, 460, 401,
	    160, 280, 460,
	    40, 399, 281,
	    159, 461, 399,
	    161, 281, 461,
	    2, 164, 313,
	    44, 462, 164,
	    73, 313, 462,
	    14, 222, 284,
	    102, 463, 222,
	    44, 284, 463,
	    13, 193, 342,
	    73, 464, 193,
	    102, 342, 464,
	    0, 162, 314,
	    42, 465, 162,
	    74, 314, 465,
	    12, 223, 282,
	    103, 466, 223,
	    42, 282, 466,
	    14, 194, 343,
	    74, 467, 194,
	    103, 343, 467,
	    1, 163, 312,
	    43, 468, 163,
	    72, 312, 468,
	    13, 224, 283,
	    104, 469, 224,
	    43, 283, 469,
	    12, 192, 344,
	    72, 470, 192,
	    104, 344, 470,
	    3, 166, 315,
	    46, 471, 166,
	    75, 315, 471,
	    16, 225, 286,
	    105, 472, 225,
	    46, 286, 472,
	    15, 195, 345,
	    75, 473, 195,
	    105, 345, 473,
	    0, 314, 316,
	    74, 474, 314,
	    76, 316, 474,
	    14, 226, 194,
	    106, 475, 226,
	    74, 194, 475,
	    16, 196, 346,
	    76, 476, 196,
	    106, 346, 476,
	    2, 165, 164,
	    45, 477, 165,
	    44, 164, 477,
	    15, 227, 285,
	    107, 478, 227,
	    45, 285, 478,
	    14, 284, 347,
	    44, 479, 284,
	    107, 347, 479,
	    4, 168, 317,
	    48, 480, 168,
	    77, 317, 480,
	    18, 228, 288,
	    108, 481, 228,
	    48, 288, 481,
	    17, 197, 348,
	    77, 482, 197,
	    108, 348, 482,
	    0, 316, 318,
	    76, 483, 316,
	    78, 318, 483,
	    16, 229, 196,
	    109, 484, 229,
	    76, 196, 484,
	    18, 198, 349,
	    78, 485, 198,
	    109, 349, 485,
	    3, 167, 166,
	    47, 486, 167,
	    46, 166, 486,
	    17, 230, 287,
	    110, 487, 230,
	    47, 287, 487,
	    16, 286, 350,
	    46, 488, 286,
	    110, 350, 488,
	    5, 170, 319,
	    50, 489, 170,
	    79, 319, 489,
	    20, 231, 290,
	    111, 490, 231,
	    50, 290, 490,
	    19, 199, 351,
	    79, 491, 199,
	    111, 351, 491,
	    0, 318, 320,
	    78, 492, 318,
	    80, 320, 492,
	    18, 232, 198,
	    112, 493, 232,
	    78, 198, 493,
	    20, 200, 352,
	    80, 494, 200,
	    112, 352, 494,
	    4, 169, 168,
	    49, 495, 169,
	    48, 168, 495,
	    19, 233, 289,
	    113, 496, 233,
	    49, 289, 496,
	    18, 288, 353,
	    48, 497, 288,
	    113, 353, 497,
	    1, 312, 321,
	    72, 498, 312,
	    81, 321, 498,
	    12, 234, 192,
	    114, 499, 234,
	    72, 192, 499,
	    21, 201, 354,
	    81, 500, 201,
	    114, 354, 500,
	    0, 320, 162,
	    80, 501, 320,
	    42, 162, 501,
	    20, 235, 200,
	    115, 502, 235,
	    80, 200, 502,
	    12, 282, 355,
	    42, 503, 282,
	    115, 355, 503,
	    5, 171, 170,
	    51, 504, 171,
	    50, 170, 504,
	    21, 236, 291,
	    116, 505, 236,
	    51, 291, 505,
	    20, 290, 356,
	    50, 506, 290,
	    116, 356, 506,
	    7, 173, 322,
	    53, 507, 173,
	    82, 322, 507,
	    23, 237, 293,
	    117, 508, 237,
	    53, 293, 508,
	    22, 202, 357,
	    82, 509, 202,
	    117, 357, 509,
	    1, 321, 323,
	    81, 510, 321,
	    83, 323, 510,
	    21, 238, 201,
	    118, 511, 238,
	    81, 201, 511,
	    23, 203, 358,
	    83, 512, 203,
	    118, 358, 512,
	    5, 172, 171,
	    52, 513, 172,
	    51, 171, 513,
	    22, 239, 292,
	    119, 514, 239,
	    52, 292, 514,
	    21, 291, 359,
	    51, 515, 291,
	    119, 359, 515,
	    6, 175, 324,
	    55, 516, 175,
	    84, 324, 516,
	    25, 240, 295,
	    120, 517, 240,
	    55, 295, 517,
	    24, 204, 360,
	    84, 518, 204,
	    120, 360, 518,
	    1, 323, 325,
	    83, 519, 323,
	    85, 325, 519,
	    23, 241, 203,
	    121, 520, 241,
	    83, 203, 520,
	    25, 205, 361,
	    85, 521, 205,
	    121, 361, 521,
	    7, 174, 173,
	    54, 522, 174,
	    53, 173, 522,
	    24, 242, 294,
	    122, 523, 242,
	    54, 294, 523,
	    23, 293, 362,
	    53, 524, 293,
	    122, 362, 524,
	    2, 313, 326,
	    73, 525, 313,
	    86, 326, 525,
	    13, 243, 193,
	    123, 526, 243,
	    73, 193, 526,
	    26, 206, 363,
	    86, 527, 206,
	    123, 363, 527,
	    1, 325, 163,
	    85, 528, 325,
	    43, 163, 528,
	    25, 244, 205,
	    124, 529, 244,
	    85, 205, 529,
	    13, 283, 364,
	    43, 530, 283,
	    124, 364, 530,
	    6, 176, 175,
	    56, 531, 176,
	    55, 175, 531,
	    26, 245, 296,
	    125, 532, 245,
	    56, 296, 532,
	    25, 295, 365,
	    55, 533, 295,
	    125, 365, 533,
	    8, 178, 327,
	    58, 534, 178,
	    87, 327, 534,
	    28, 246, 298,
	    126, 535, 246,
	    58, 298, 535,
	    27, 207, 366,
	    87, 536, 207,
	    126, 366, 536,
	    2, 326, 328,
	    86, 537, 326,
	    88, 328, 537,
	    26, 247, 206,
	    127, 538, 247,
	    86, 206, 538,
	    28, 208, 367,
	    88, 539, 208,
	    127, 367, 539,
	    6, 177, 176,
	    57, 540, 177,
	    56, 176, 540,
	    27, 248, 297,
	    128, 541, 248,
	    57, 297, 541,
	    26, 296, 368,
	    56, 542, 296,
	    128, 368, 542,
	    3, 315, 329,
	    75, 543, 315,
	    89, 329, 543,
	    15, 249, 195,
	    129, 544, 249,
	    75, 195, 544,
	    29, 209, 369,
	    89, 545, 209,
	    129, 369, 545,
	    2, 328, 165,
	    88, 546, 328,
	    45, 165, 546,
	    28, 250, 208,
	    130, 547, 250,
	    88, 208, 547,
	    15, 285, 370,
	    45, 548, 285,
	    130, 370, 548,
	    8, 179, 178,
	    59, 549, 179,
	    58, 178, 549,
	    29, 251, 299,
	    131, 550, 251,
	    59, 299, 550,
	    28, 298, 371,
	    58, 551, 298,
	    131, 371, 551,
	    9, 181, 330,
	    61, 552, 181,
	    90, 330, 552,
	    31, 252, 301,
	    132, 553, 252,
	    61, 301, 553,
	    30, 210, 372,
	    90, 554, 210,
	    132, 372, 554,
	    3, 329, 331,
	    89, 555, 329,
	    91, 331, 555,
	    29, 253, 209,
	    133, 556, 253,
	    89, 209, 556,
	    31, 211, 373,
	    91, 557, 211,
	    133, 373, 557,
	    8, 180, 179,
	    60, 558, 180,
	    59, 179, 558,
	    30, 254, 300,
	    134, 559, 254,
	    60, 300, 559,
	    29, 299, 374,
	    59, 560, 299,
	    134, 374, 560,
	    4, 317, 332,
	    77, 561, 317,
	    92, 332, 561,
	    17, 255, 197,
	    135, 562, 255,
	    77, 197, 562,
	    32, 212, 375,
	    92, 563, 212,
	    135, 375, 563,
	    3, 331, 167,
	    91, 564, 331,
	    47, 167, 564,
	    31, 256, 211,
	    136, 565, 256,
	    91, 211, 565,
	    17, 287, 376,
	    47, 566, 287,
	    136, 376, 566,
	    9, 182, 181,
	    62, 567, 182,
	    61, 181, 567,
	    32, 257, 302,
	    137, 568, 257,
	    62, 302, 568,
	    31, 301, 377,
	    61, 569, 301,
	    137, 377, 569,
	    10, 184, 333,
	    64, 570, 184,
	    93, 333, 570,
	    34, 258, 304,
	    138, 571, 258,
	    64, 304, 571,
	    33, 213, 378,
	    93, 572, 213,
	    138, 378, 572,
	    4, 332, 334,
	    92, 573, 332,
	    94, 334, 573,
	    32, 259, 212,
	    139, 574, 259,
	    92, 212, 574,
	    34, 214, 379,
	    94, 575, 214,
	    139, 379, 575,
	    9, 183, 182,
	    63, 576, 183,
	    62, 182, 576,
	    33, 260, 303,
	    140, 577, 260,
	    63, 303, 577,
	    32, 302, 380,
	    62, 578, 302,
	    140, 380, 578,
	    5, 319, 335,
	    79, 579, 319,
	    95, 335, 579,
	    19, 261, 199,
	    141, 580, 261,
	    79, 199, 580,
	    35, 215, 381,
	    95, 581, 215,
	    141, 381, 581,
	    4, 334, 169,
	    94, 582, 334,
	    49, 169, 582,
	    34, 262, 214,
	    142, 583, 262,
	    94, 214, 583,
	    19, 289, 382,
	    49, 584, 289,
	    142, 382, 584,
	    10, 185, 184,
	    65, 585, 185,
	    64, 184, 585,
	    35, 263, 305,
	    143, 586, 263,
	    65, 305, 586,
	    34, 304, 383,
	    64, 587, 304,
	    143, 383, 587,
	    7, 322, 336,
	    82, 588, 322,
	    96, 336, 588,
	    22, 264, 202,
	    144, 589, 264,
	    82, 202, 589,
	    36, 216, 384,
	    96, 590, 216,
	    144, 384, 590,
	    5, 335, 172,
	    95, 591, 335,
	    52, 172, 591,
	    35, 265, 215,
	    145, 592, 265,
	    95, 215, 592,
	    22, 292, 385,
	    52, 593, 292,
	    145, 385, 593,
	    10, 186, 185,
	    66, 594, 186,
	    65, 185, 594,
	    36, 266, 306,
	    146, 595, 266,
	    66, 306, 595,
	    35, 305, 386,
	    65, 596, 305,
	    146, 386, 596,
	    11, 188, 337,
	    68, 597, 188,
	    97, 337, 597,
	    38, 267, 308,
	    147, 598, 267,
	    68, 308, 598,
	    37, 217, 387,
	    97, 599, 217,
	    147, 387, 599,
	    6, 324, 338,
	    84, 600, 324,
	    98, 338, 600,
	    24, 268, 204,
	    148, 601, 268,
	    84, 204, 601,
	    38, 218, 388,
	    98, 602, 218,
	    148, 388, 602,
	    7, 187, 174,
	    67, 603, 187,
	    54, 174, 603,
	    37, 269, 307,
	    149, 604, 269,
	    67, 307, 604,
	    24, 294, 389,
	    54, 605, 294,
	    149, 389, 605,
	    8, 327, 339,
	    87, 606, 327,
	    99, 339, 606,
	    27, 270, 207,
	    150, 607, 270,
	    87, 207, 607,
	    39, 219, 390,
	    99, 608, 219,
	    150, 390, 608,
	    6, 338, 177,
	    98, 609, 338,
	    57, 177, 609,
	    38, 271, 218,
	    151, 610, 271,
	    98, 218, 610,
	    27, 297, 391,
	    57, 611, 297,
	    151, 391, 611,
	    11, 189, 188,
	    69, 612, 189,
	    68, 188, 612,
	    39, 272, 309,
	    152, 613, 272,
	    69, 309, 613,
	    38, 308, 392,
	    68, 614, 308,
	    152, 392, 614,
	    11, 337, 340,
	    97, 615, 337,
	    100, 340, 615,
	    37, 273, 217,
	    153, 616, 273,
	    97, 217, 616,
	    40, 220, 393,
	    100, 617, 220,
	    153, 393, 617,
	    7, 336, 187,
	    96, 618, 336,
	    67, 187, 618,
	    36, 274, 216,
	    154, 619, 274,
	    96, 216, 619,
	    37, 307, 394,
	    67, 620, 307,
	    154, 394, 620,
	    10, 190, 186,
	    70, 621, 190,
	    66, 186, 621,
	    40, 275, 310,
	    155, 622, 275,
	    70, 310, 622,
	    36, 306, 395,
	    66, 623, 306,
	    155, 395, 623,
	    9, 330, 341,
	    90, 624, 330,
	    101, 341, 624,
	    30, 276, 210,
	    156, 625, 276,
	    90, 210, 625,
	    41, 221, 396,
	    101, 626, 221,
	    156, 396, 626,
	    8, 339, 180,
	    99, 627, 339,
	    60, 180, 627,
	    39, 277, 219,
	    157, 628, 277,
	    99, 219, 628,
	    30, 300, 397,
	    60, 629, 300,
	    157, 397, 629,
	    11, 191, 189,
	    71, 630, 191,
	    69, 189, 630,
	    41, 278, 311,
	    158, 631, 278,
	    71, 311, 631,
	    39, 309, 398,
	    69, 632, 309,
	    158, 398, 632,
	    10, 333, 190,
	    93, 633, 333,
	    70, 190, 633,
	    33, 279, 213,
	    159, 634, 279,
	    93, 213, 634,
	    40, 310, 399,
	    70, 635, 310,
	    159, 399, 635,
	    9, 341, 183,
	    101, 636, 341,
	    63, 183, 636,
	    41, 280, 221,
	    160, 637, 280,
	    101, 221, 637,
	    33, 303, 400,
	    63, 638, 303,
	    160, 400, 638,
	    11, 340, 191,
	    100, 639, 340,
	    71, 191, 639,
	    40, 281, 220,
	    161, 640, 281,
	    100, 220, 640,
	    41, 311, 401,
	    71, 641, 311,
	    161, 401, 641
	};

	GLuint result = glGenLists(1);
	glNewList(result, GL_COMPILE);
	

	glEnableClientState(GL_VERTEX_ARRAY);
	glVertexPointer(
	    3,
	    GL_FLOAT,
	    0,  
	    SPHERE_MODEL_PTS
        );

	glEnableClientState(GL_NORMAL_ARRAY);
	glNormalPointer(
	    GL_FLOAT,
	    0,  
	    SPHERE_MODEL_PTS
	);
	
	glDrawElements(
	    GL_TRIANGLES,
	    GLsizei(SPHERE_MODEL_NB_TRIANGLES*3),
	    GL_UNSIGNED_SHORT,
	    SPHERE_MODEL_TRIANGLES
	);

	glDisableClientState(GL_VERTEX_ARRAY);
	glDisableClientState(GL_NORMAL_ARRAY);

	glEndList();
	return result;
    }
#else
    GLuint create_sphere_display_list() {
	return 0;
    }
#endif

}
